==> http-header-authorization-0.0.4.tgz: package/test/basic-authorization-tests.js <==
const basicAuthorization = require('../index').basicAuthorization;
const EventEmitter = require('events');
const expect = require('chai').expect;

describe('basic-authorization.js', () => {
  function createBasicAuthorizationHeader(username, password) {
    const token = new Buffer(`${username}:${password}`).toString('base64');
    const header = `Basic ${token}`;
    return header;
  }

  const username = 'Hello';
  const password = 'World';

  beforeEach(() => {
    process.env.API_USERNAME = username;
    process.env.API_PASSWORD = password;
  });

  afterEach(() => {
    delete process.env.API_USERNAME;
    delete process.env.API_PASSWORD;
  });

  describe('authorize', () => {
    it('it should return false if the token is incorrect.', () => {
      const header = createBasicAuthorizationHeader('nottheusername', 'notthepassword');
      const result = basicAuthorization.authorize(header, username, password);
      expect(result).to.eql(false);
    });

    it('it should return true if the token is correct.', () => {
      const header = createBasicAuthorizationHeader(username, password);
      const result = basicAuthorization.authorize(header, username, password);
      expect(result).to.eql(true);
    });
  });

  describe('authorizeRequest', () => {
    let req;
    beforeEach(() => { req = new EventEmitter(); });

    describe('if req.header.authorization is provided with the correct Basic Authorization digest', () => {
      beforeEach(() => {
        req.headers = {
          authorization: createBasicAuthorizationHeader(username, password),
        };
      });

      it('it should call next.', (done) => {
        basicAuthorization.authorizeRequest(req, null, done);
      });

      it('it should emit a request-authorized event.', (done) => {
        basicAuthorization.authorizeRequest(req, null, () => {
          req.on('request-authorized', done);
        });
      });
    });

    describe('if req.headers.authorization is not provided', () => {
      beforeEach(() => { req.headers = {}; });
      it('it should call next with an authorization error.', (done) => {
        basicAuthorization.authorizeRequest(req, null, (err) => {
          expect(err.isAuthorizationError).to.eql(true);
          done();
        });
      });

      it('it should emit a request-unauthorized event.', (done) => {
        basicAuthorization.authorizeRequest(req, null, (err) => {
          req.on('request-unauthorized', (event) => {
            expect(event).to.eql({ err });
            done();
          });
        });
      });
    });

    describe('if req.headers.authorization is a not the correct Basic digest', () => {
      beforeEach(() => {
        req.headers = {
          authorization: createBasicAuthorizationHeader('wrongusername', 'wrongpassword'),
        };
      });

      it('it should call next with an authorization error.', (done) => {
        basicAuthorization.authorizeRequest(req, null, (err) => {
          expect(err.isAuthorizationError).to.eql(true);
          done();
        });
      });

      it('it should emit a request-unauthorized event.', (done) => {
        basicAuthorization.authorizeRequest(req, null, (err) => {
          req.on('request-unauthorized', (event) => {
            expect(event).to.eql({ err });
            done();
          });
        });
      });
    });
  });
});

==> http-header-authorization-0.0.5.tgz: package/test/basic-authorization-tests.js <==
const basicAuthorization = require('../index').basicAuthorization;
const EventEmitter = require('events');
const expect = require('chai').expect;

describe('basic-authorization.js', () => {
  function createBasicAuthorizationHeader(username, password) {
    const token = new Buffer(`${username}:${password}`).toString('base64');
    const header = `Basic ${token}`;
    return header;
  }

  const username = 'Hello';
  const password = 'World';

  beforeEach(() => {
    process.env.API_USERNAME = username;
    process.env.API_PASSWORD = password;
  });

  afterEach(() => {
    delete process.env.API_USERNAME;
    delete process.env.API_PASSWORD;
  });

  describe('authorize', () => {
    it('it should return false if the token is incorrect.', () => {
      const header = createBasicAuthorizationHeader('nottheusername', 'notthepassword');
      const result = basicAuthorization.authorize(header, username, password);
      expect(result).to.eql(false);
    });

    it('it should return true if the token is correct.', () => {
      const header = createBasicAuthorizationHeader(username, password);
      const result = basicAuthorization.authorize(header, username, password);
      expect(result).to.eql(true);
    });
  });

  describe('authorizeRequest', () => {
    let req;
    beforeEach(() => { req = new EventEmitter(); });

    describe('if req.header.authorization is provided with the correct Basic Authorization digest', () => {
      beforeEach(() => {
        req.headers = {
          authorization: createBasicAuthorizationHeader(username, password),
        };
        req.originalUrl = '/api/a/1234567890';
      });

      it('it should call next.', (done) => {
        basicAuthorization.authorizeRequest(req, null, done);
      });

      it('it should emit a request-authorized event.', (done) => {
        basicAuthorization.authorizeRequest(req, null, () => {
          req.on('request-authorized', (event) => {
            expect(event).to.eql({ url: req.originalUrl });
            done();
          });
        });
      });
    });

    describe('if req.headers.authorization is not provided', () => {
      beforeEach(() => {
        req.headers = {};
        req.originalUrl = '/api/a/1234567890';
      });
      it('it should call next with an authorization error.', (done) => {
        basicAuthorization.authorizeRequest(req, null, (err) => {
          expect(err.isAuthorizationError).to.eql(true);
          done();
        });
      });

      it('it should emit a request-unauthorized event.', (done) => {
        basicAuthorization.authorizeRequest(req, null, (err) => {
          req.on('request-unauthorized', (event) => {
            expect(event).to.eql({ err, url: req.originalUrl });
            done();
          });
        });
      });
    });

    describe('if req.headers.authorization is a not the correct Basic digest', () => {
      beforeEach(() => {
        req.headers = {
          authorization: createBasicAuthorizationHeader('wrongusername', 'wrongpassword'),
        };
        req.originalUrl = '/api/a/1234567890';
      });

      it('it should call next with an authorization error.', (done) => {
        basicAuthorization.authorizeRequest(req, null, (err) => {
          expect(err.isAuthorizationError).to.eql(true);
          done();
        });
      });

      it('it should emit a request-unauthorized event.', (done) => {
        basicAuthorization.authorizeRequest(req, null, (err) => {
          req.on('request-unauthorized', (event) => {
            expect(event).to.eql({ err, url: req.originalUrl });
            done();
          });
        });
      });
    });
  });
});
